__version__ = "0.6.1"

from .impl import (
    del_dict_set,
    del_dict_tuple,
    pop_dict_set,
    pop_dict_set_if_none,
    pop_dict_tuple,
)

__all__ = [
    "del_dict_set",
    "del_dict_tuple",
    "pop_dict_set",
    "pop_dict_set_if_none",
    "pop_dict_tuple",
]
